#!/bin/sh
module_name="ElephantDrive"
sqlite="/opt/bin/sqlite"
module_path="/raid/data/module/${module_name}"
register_path="${module_path}/sys/tmp/register"
CONFIG_DIR="${module_path}/sys/conf"
conffile="${CONFIG_DIR}/elephantdrive.config"
confdb="${module_path}/sys/etc/elephantdrive.db"
logfile="${module_path}/sys/var/log/elephantdrive.log"
statusfile="${module_path}/sys/var/lib/elephantdrive/status"
export LD_LIBRARY_PATH=/raid/data/module/ElephantDrive/sys/lib64/:/raid/data/module/ElephantDrive/sys/lib/:/opt/lib64/:/usr/lib64/:$LD_LIBRARY_PATH

if [ -f "/opt/bin/wget" ];then
  wget="/opt/bin/wget"
else
  wget="/usr/bin/wget"
fi

start(){

  enable=`${sqlite} ${confdb} "select v from conf where k='elephant_enable'"`
  if [ "${enable}" == "1" ];then
    email=`${sqlite} ${confdb} "select v from conf where k='email'"`
    password=`${sqlite} ${confdb} "select v from conf where k='password'"`

    if [ "${email}" != "" ] && [ "${password}" != "" ];then
      echo "username ${email}" > ${conffile}
      echo "password ${password}" >> ${conffile}

			${module_path}/bin/elephantdrive -D -c ${CONFIG_DIR} \
			"MonitorConfigChanges=true" \
			"AppRoot=/raid/data/module/ElephantDrive/sys" \
			"SmbConfFile=/etc/samba/smb.conf" \
			"SmbIngoredAliases=_NAS_Recycle_RAID;_NAS_Recycle_RAID2;_NAS_Recycle_RAID3;_NAS_Recycle_RAID4;_Module_Folder_;_NAS_Module_Source_"
    fi
  fi
}

stop(){
  ${module_path}/bin/elephantdrive -K
  sleep 2
  
  if [ -f "${conffile}" ];then
    rm "${conffile}"
  fi
 
  if [ -f "${statusfile}" ];then
    rm "${statusfile}"
  fi
}

status(){
  ${module_path}/bin/elephantdrive -S
	return $?
}

check_email(){
  email=$1
  mkdir ${register_path}
  cd ${register_path}
  url="https://www.vaultservices.net/partners/vaultservices/genacct.aspx?a=check&u=${email}"

  ${wget} --no-check-certificate ${url}

  ret=`cat ${register_path}/* | grep "lblResult" | sed 's/<span id="lblResult">//g' | sed 's/<\/span>//g'`

  rm ${register_path}/*
  echo ${ret}
}

register(){
  email=$1
  encrypted_password=$2
  mkdir ${register_path}
  cd ${register_path}

  url="https://www.vaultservices.net/partners/vaultservices/genacct.aspx?a=reg&u=${email}&t=${encrypted_password}&c=922&p=57"

  ${wget} --no-check-certificate ${url}

  ret=`cat ${register_path}/* | grep "lblResult" | sed 's/<span id="lblResult">//g' | sed 's/<\/span>//g'`

  rm ${register_path}/*
  echo ${ret}
}

get_log(){
  tail -n 2000 ${logfile} > ${logfile}.tmp
	chmod ugo+w ${logfile}.tmp
}

version(){
	${module_path}/bin/elephantdrive -V
}

case "$1" in
  boot|start)
    start
    ;;
  stop)
    stop
    ;;
  status)
    status
		sts=$?
		if [ $sts -eq 0 ]; then
				echo "running"
		else
				echo "stopped"
		fi
		exit $sts
    ;;
  check_email)
    check_email "$2"
    ;;
  register)
    register "$2" "$3"
    ;;
  version)
    version
    ;;
  get_log)
    get_log
    ;;
  *)
    echo "Usage: {start|stop|status|version}" 
    exit 1
    ;;
esac

